@@ -7,7 +7,7 @@
 #' variance, Peto method, and generalised linear mixed model (GLMM)
 #' are available for pooling. For GLMMs, the
 #' \code{\link[metafor]{rma.glmm}} function from R package
-#' \bold{metafor} (Viechtbauer 2010) is called internally.
+#' \bold{metafor} (Viechtbauer, 2010) is called internally.
 #' 
 #' @param event.e Number of events in experimental group.
 #' @param n.e Number of observations in experimental group.
@@ -124,7 +124,9 @@
 #' 
 #' @details
 #' Treatment estimates and standard errors are calculated for each
-#' study. The following measures of treatment effect are available:
+#' study. The following measures of treatment effect are available
+#' (Rücker et al., 2009):
+#' 
 #' \itemize{
 #' \item Risk ratio (\code{sm = "RR"})
 #' \item Odds ratio (\code{sm = "OR"})
@@ -132,33 +134,28 @@
 #' \item Arcsine difference (\code{sm = "ASD"})
 #' }
 #' 
-#' For several arguments defaults settings are utilised (assignments
-#' using \code{\link{gs}} function). These defaults can be changed
-#' using the \code{\link{settings.meta}} function.
-#' 
-#' Internally, both fixed effect and random effects models are
-#' calculated regardless of values chosen for arguments
-#' \code{comb.fixed} and \code{comb.random}. Accordingly, the estimate
-#' for the random effects model can be extracted from component
-#' \code{TE.random} of an object of class \code{"meta"} even if
-#' argument \code{comb.random = FALSE}. However, all functions in R
-#' package \bold{meta} will adequately consider the values for
-#' \code{comb.fixed} and \code{comb.random}. E.g. function
-#' \code{\link{print.meta}} will not print results for the random
-#' effects model if \code{comb.random = FALSE}.
-#' 
 #' By default, both fixed effect and random effects models are
 #' considered (see arguments \code{comb.fixed} and
 #' \code{comb.random}). If \code{method} is \code{"MH"} (default), the
-#' Mantel-Haenszel method is used to calculate the fixed effect
-#' estimate; if \code{method} is \code{"Inverse"}, inverse variance
-#' weighting is used for pooling; if \code{method} is \code{"Peto"},
-#' the Peto method is used for pooling. For the Peto method, Peto's
-#' log odds ratio, i.e. \code{(O - E) / V} and its standard error
-#' \code{sqrt(1 / V)} with \code{O - E} and \code{V} denoting
-#' "Observed minus Expected" and "V", are utilised in the random
-#' effects model. Accordingly, results of a random effects model using
-#' \code{sm = "Peto"} can be (slightly) different to results from a
+#' Mantel-Haenszel method (Greenland & Robins, 1985; Robins et al.,
+#' 1986) is used to calculate the fixed effect estimate; if
+#' \code{method} is \code{"Inverse"}, inverse variance weighting is
+#' used for pooling (Fleiss, 1993); if \code{method} is \code{"Peto"},
+#' the Peto method is used for pooling (Yussuf et al., 1985).
+#'
+#' While the Mantel-Haenszel and Peto method are defined under the
+#' fixed effect model, random effects variants based on these methods
+#' are also implemented in \code{metabin}. Following RevMan 5, the
+#' Mantel-Haenszel estimator is used in the calculation of the
+#' between-study heterogeneity statistic Q which is used in the
+#' DerSimonian-Laird estimator. Accordlingly, the results for the
+#' random effects meta-analysis using the Mantel-Haenszel or inverse
+#' variance method are typically very similar. For the Peto method,
+#' Peto's log odds ratio, i.e. \code{(O-E) / V} and its standard error
+#' \code{sqrt(1 / V)} with \code{O-E} and \code{V} denoting
+#' "Observed minus Expected" and its variance, are utilised in the
+#' random effects model. Accordingly, results of a random effects
+#' model using \code{sm = "Peto"} can be different to results from a
 #' random effects model using \code{sm = "MH"} or \code{sm =
 #' "Inverse"}.
 #' 
@@ -196,7 +193,7 @@
 #' }
 #'
 #' Details on these four GLMMs as well as additional arguments which
-#' can be provided using argument '\code{\dots{}}' in \code{metabin}
+#' can be provided using argument '\code{\dots}' in \code{metabin}
 #' are described in \code{\link[metafor]{rma.glmm}} where you can also
 #' find information on the iterative algorithms used for estimation.
 #' Note, regardless of which value is used for argument
@@ -204,6 +201,21 @@
 #' fixed effect model (with fixed treatment effect) and random effects
 #' model (with random treatment effects).
 #' 
+#' For several arguments defaults settings are utilised (assignments
+#' using \code{\link{gs}} function). These defaults can be changed
+#' using the \code{\link{settings.meta}} function.
+#' 
+#' Internally, both fixed effect and random effects models are
+#' calculated regardless of values chosen for arguments
+#' \code{comb.fixed} and \code{comb.random}. Accordingly, the estimate
+#' for the random effects model can be extracted from component
+#' \code{TE.random} of an object of class \code{"meta"} even if
+#' argument \code{comb.random = FALSE}. However, all functions in R
+#' package \bold{meta} will adequately consider the values for
+#' \code{comb.fixed} and \code{comb.random}. E.g. function
+#' \code{\link{print.meta}} will not print results for the random
+#' effects model if \code{comb.random = FALSE}.
+#' 
 #' For studies with a zero cell count, by default, 0.5 is added to all
 #' cell frequencies of these studies; if \code{incr} is \code{"TACC"}
 #' a treatment arm continuity correction is used instead (Sweeting et
@@ -229,13 +241,17 @@
 #' group.
 #' 
 #' Argument \code{byvar} can be used to conduct subgroup analysis for
-#' all methods but GLMMs. Instead use the \code{\link{metareg}}
-#' function for GLMMs which can also be used for continuous
+#' a categorical covariate. The \code{\link{metareg}} function can be
+#' used instead for more than one categorical covariate or continuous
 #' covariates.
 #' 
-#' A prediction interval for the treatment effect of a new study is
-#' calculated (Higgins et al., 2009) if arguments \code{prediction}
-#' and \code{comb.random} are \code{TRUE}.
+#' A prediction interval for the proportion in a new study (Higgins et
+#' al., 2009) is calculated if arguments \code{prediction} and
+#' \code{comb.random} are \code{TRUE}. Note, the definition of
+#' prediction intervals varies in the literature. This function
+#' implements equation (12) of Higgins et al., (2009) which proposed a
+#' \emph{t} distribution with \emph{K-2} degrees of freedom where
+#' \emph{K} corresponds to the number of studies in the meta-analysis.
 #' 
 #' R function \code{\link{update.meta}} can be used to redo the
 #' meta-analysis of an existing metabin object by only specifying
@@ -247,18 +263,12 @@
 #' Hartung (2003) is implemented, see description of argument
 #' \code{tdist} in \code{\link[metafor]{rma.glmm}}.
 #' 
-#' The DerSimonian-Laird estimate (1986) is used in the random effects
-#' model if \code{method.tau = "DL"}. The iterative Paule-Mandel
-#' method (1982) to estimate the between-study variance is used if
-#' argument \code{method.tau = "PM"}. Internally, R function
-#' \code{paulemandel} is called which is based on R function
-#' mpaule.default from R package \bold{metRology} from S.L.R. Ellison
-#' <s.ellison at lgc.co.uk>.
-#' 
-#' If R package \bold{metafor} (Viechtbauer 2010) is installed, the
-#' following methods to estimate the between-study variance
-#' \eqn{\tau^2} (argument \code{method.tau}) are also available:
+#' The following methods to estimate the between-study variance
+#' \eqn{\tau^2} (argument \code{method.tau}) are available for the
+#' inverse variance method:
 #' \itemize{
+#' \item DerSimonian-Laird estimator (\code{method.tau = "DL"})
+#' \item Paule-Mandel estimator (\code{method.tau = "PM"})
 #' \item Restricted maximum-likelihood estimator (\code{method.tau =
 #'   "REML"})
 #' \item Maximum-likelihood estimator (\code{method.tau = "ML"})
@@ -267,10 +277,9 @@
 #' \item Hedges estimator (\code{method.tau = "HE"})
 #' \item Empirical Bayes estimator (\code{method.tau = "EB"})
 #' }
-#' For these methods the R function \code{rma.uni} of R package
-#' \bold{metafor} is called internally. See help page of R function
-#' \code{rma.uni} for more details on these methods to estimate
-#' between-study variance.
+#' See \code{\link{metagen}} for more information on these
+#' estimators. Note, the maximum-likelihood method is utilized for
+#' GLMMs.
 #' 
 #' @return
 #' An object of class \code{c("metabin", "meta")} with corresponding
@@ -327,8 +336,7 @@
 #' \item{df.Q.LRT}{Degrees of freedom for likelihood-ratio test}
 #' \item{pval.Q.LRT}{P-value of likelihood-ratio test.}
 #' \item{tau}{Square-root of between-study variance.}
-#' \item{se.tau}{Standard error of square-root of between-study
-#'   variance.}
+#' \item{se.tau2}{Standard error of between-study variance.}
 #' \item{C}{Scaling factor utilised internally to calculate common
 #'   tau-squared across subgroups.}
 #' \item{Q.CMH}{Cochran-Mantel-Haenszel test statistic for overall
@@ -370,9 +378,6 @@
 #' \item{df.hakn.w}{Degrees of freedom for test of treatment effect
 #'   for Hartung-Knapp method in subgroups - if \code{byvar} is not
 #'   missing and \code{hakn = TRUE}.}
-#' \item{n.harmonic.mean.w}{Harmonic mean of number of observations in
-#'   subgroups (for back transformation of Freeman-Tukey Double
-#'   arcsine transformation) - if \code{byvar} is not missing.}
 #' \item{event.e.w}{Number of events in experimental group in
 #'   subgroups - if \code{byvar} is not missing.}
 #' \item{n.e.w}{Number of observations in experimental group in
@@ -505,12 +510,18 @@
 #' variate.
 #' \emph{Biometrika},
 #' \bold{73}, 425--35
+#'
+#' Robins J, Breslow N, Greenland S (1986):
+#' Estimators of the Mantel-Haenszel Variance Consistent in Both
+#' Sparse Data and Large-Strata Limiting Models.
+#' \emph{Biometrics},
+#' \bold{42}, 311--23
 #' 
-#' Rücker G, Schwarzer G, Carpenter JR (2008):
-#' Arcsine test for publication bias in meta-analyses with binary
-#' outcomes.
+#' Rücker G, Schwarzer G, Carpenter J, Olkin I (2009):
+#' Why add anything to nothing? The arcsine difference as a measure of
+#' treatment effect in meta-analysis with zero cells.
 #' \emph{Statistics in Medicine},
-#' \bold{27}, 746--63
+#' \bold{28}, 721--38
 #' 
 #' Simmonds MC, Higgins JP (2016):
 #' A general framework for the use of logistic regression models in
@@ -536,9 +547,15 @@
 #' \bold{23}, 1351--75
 #' 
 #' Viechtbauer W (2010):
-#' Conducting Meta-Analyses in R with the Metafor Package.
+#' Conducting meta-analyses in R with the metafor package.
 #' \emph{Journal of Statistical Software},
 #' \bold{36}, 1--48
+#'
+#' Yusuf S, Peto R, Lewis J, Collins R, Sleight P (1985):
+#' Beta blockade during and after myocardial infarction: An overview
+#' of the randomized trials.
+#' \emph{Progress in Cardiovascular Diseases},
+#' \bold{27}, 335--71
 #' 
 #' @examples
 #' # Calculate odds ratio and confidence interval for a single study
@@ -758,6 +775,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   }
   ##
   method <- setchar(method, c("Inverse", "MH", "Peto", "GLMM"))
+  is.glmm <- method == "GLMM"
   ##
   chklogical(allincr)
   chklogical(addincr)
@@ -766,7 +784,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   chklogical(RR.cochrane)
   ##
   model.glmm <- setchar(model.glmm, c("UM.FS", "UM.RS", "CM.EL", "CM.AL"))
-  if (method == "GLMM" & model.glmm == "CM.EL")
+  if (is.glmm & model.glmm == "CM.EL")
     is.installed.package("BiasedUrn", fun, "model.glmm", " = \"CM.EL\"")
   ##
   chklogical(print.CMH)
@@ -777,10 +795,10 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   if (method == "Peto" & sm != "OR")
     stop("Peto's method only possible with argument 'sm = \"OR\"'")
   ##
-  if (method == "GLMM" & sm != "OR")
+  if (is.glmm & sm != "OR")
     stop("Generalised linear mixed models only possible with argument 'sm = \"OR\"'.")
   ##
-  if (method == "GLMM" & method.tau != "ML")
+  if (is.glmm & method.tau != "ML")
     stop("Generalised linear mixed models only possible with argument 'method.tau = \"ML\"'.")
 
 
@@ -836,13 +854,6 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   byvar <- eval(mf[[match("byvar", names(mf))]],
                 data, enclos = sys.frame(sys.parent()))
   by <- !is.null(byvar)
-  if (method == "GLMM" & by) {
-    if (warn)
-      warning("Argument 'byvar' not considered for GLMMs. Use metareg ",
-              "function for subgroup analysis of GLMM meta-analyses.")
-    byvar <- NULL
-    by <- FALSE
-  }
   ##
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
@@ -871,12 +882,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ##
   ## Additional checks
   ##
-  if (method == "GLMM") {
-    if (tau.common) {
-      if (warn)
-        warning("Argument 'tau.common' not considered for GLMM.")
-      tau.common <- FALSE
-    }
+  if (is.glmm) {
     if (!is.null(TE.tau)) {
       if (warn)
         warning("Argument 'TE.tau' not considered for GLMM.")
@@ -1113,7 +1119,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
           warning("Note, no continuity correction considered ",
                   "for method = \"Peto\".")
       }
-      else if (method == "GLMM") {
+      else if (is.glmm) {
         if ((sparse | addincr) & warn)
           warning("Note, for method = \"GLMM\", continuity correction ",
                   "only used to calculate individual study results.")
@@ -1361,7 +1367,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     ##
     w.fixed[is.na(w.fixed)] <- 0
   }
-  else if (method == "GLMM") {
+  else if (is.glmm) {
     glmm.fixed <- rma.glmm(ai = event.e[!exclude], n1i = n.e[!exclude],
                            ci = event.c[!exclude], n2i = n.c[!exclude],
                            method = "FE", test = ifelse(hakn, "t", "z"),
@@ -1463,7 +1469,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
     res$pval.fixed <- ci.f$p
   }
   ##
-  if (method == "GLMM") {
+  if (is.glmm) {
     ##
     if (sum(!exclude) > 1)
       glmm.random <- rma.glmm(ai = event.e[!exclude], n1i = n.e[!exclude],
@@ -1557,10 +1563,17 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
       res$tau.resid <- NA
     }
     else {
-      res <- c(res, subgroup(res, hcc$tau))
-      res$Q.w.random <- hcc$Q
-      res$df.Q.w.random <- hcc$df.Q
-      res$tau.resid <- hcc$tau
+      if (is.glmm) {
+        res <- c(res, subgroup(res, NULL,
+                               factor(res$byvar, bylevs(res$byvar)), ...))
+        res$tau.resid <- NA
+      }
+      else {
+        res <- c(res, subgroup(res, hcc$tau))
+        res$Q.w.random <- hcc$Q
+        res$df.Q.w.random <- hcc$df.Q
+        res$tau.resid <- hcc$tau
+      }
     }
     ##
     if (!tau.common || method.tau == "DL") {
@@ -1569,14 +1582,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
       res$H.resid <- ci.H.resid$TE
       res$lower.H.resid <- ci.H.resid$lower
       res$upper.H.resid <- ci.H.resid$upper
-    }
-    else {
-      res$H.resid <- hcc$H.resid
-      res$lower.H.resid <- hcc$lower.H.resid
-      res$upper.H.resid <- hcc$upper.H.resid
-    }
-    ##
-    if (!tau.common || method.tau == "DL") {
+      ##
       ci.I2.resid <- isquared(res$Q.w.fixed, res$df.Q.w, level.comb)
       ##
       res$I2.resid <- ci.I2.resid$TE
@@ -1584,9 +1590,28 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
       res$upper.I2.resid <- ci.I2.resid$upper
     }
     else {
-      res$I2.resid <- hcc$I2.resid
-      res$lower.I2.resid <- hcc$lower.I2.resid
-      res$upper.I2.resid <- hcc$upper.I2.resid
+      if (is.glmm) {
+        ci.H.resid <- calcH(res$Q.w.fixed, res$df.Q.w, level.comb)
+        ##
+        res$H.resid <- ci.H.resid$TE
+        res$lower.H.resid <- ci.H.resid$lower
+        res$upper.H.resid <- ci.H.resid$upper
+        ##
+        ci.I2.resid <- isquared(res$Q.w.fixed, res$df.Q.w, level.comb)
+        ##
+        res$I2.resid <- ci.I2.resid$TE
+        res$lower.I2.resid <- ci.I2.resid$lower
+        res$upper.I2.resid <- ci.I2.resid$upper
+      }
+      else {
+        res$H.resid <- hcc$H.resid
+        res$lower.H.resid <- hcc$lower.H.resid
+        res$upper.H.resid <- hcc$upper.H.resid
+        ##
+        res$I2.resid <- hcc$I2.resid
+        res$lower.I2.resid <- hcc$lower.I2.resid
+        res$upper.I2.resid <- hcc$upper.I2.resid
+      }
     }
     ##
     res$event.w <- NULL
