@@ -21,9 +21,8 @@
 #'   used for pooling of studies. One of \code{"Inverse"} and
 #'   \code{"GLMM"}, can be abbreviated.
 #' @param sm A character string indicating which summary measure
-#'   (\code{"PFT"}, \code{"PAS"}, \code{"PRAW"}, \code{"PLN"}, or
-#'   \code{"PLOGIT"}) is to be used for pooling of studies, see
-#'   Details.
+#'   (\code{"PLOGIT"}, \code{"PAS"}, \code{"PFT"}, \code{"PLN"}, or
+#'   \code{"PRAW"}) is to be used for pooling of studies, see Details.
 #' @param incr A numeric which is added to event number and sample
 #'   size of studies with zero or all events, i.e., studies with an
 #'   event probability of either 0 or 1.
@@ -109,50 +108,76 @@
 #' 
 #' \itemize{
 #' \item Logit transformation (\code{sm = "PLOGIT"}, default)
-#' \item Log transformation (\code{sm = "PLN"})
-#' \item Freeman-Tukey Double arcsine transformation (\code{sm = "PFT"})
 #' \item Arcsine transformation (\code{sm = "PAS"})
+#' \item Freeman-Tukey Double arcsine transformation (\code{sm = "PFT"})
+#' \item Log transformation (\code{sm = "PLN"})
 #' \item Raw, i.e. untransformed, proportions (\code{sm = "PRAW"})
 #' }
 #'
-#' Classic meta-analysis (Borenstein et al., 2010) utilises the
-#' transformed proportions and corresponding standard errors in the
-#' generic inverse variance method. A distinctive and frequently
-#' overlooked advantage of binary data is that individual patient data
-#' can be extracted. Accordingly, a generalised linear mixed model
-#' (GLMM) - more specific, a random intercept logistic regression
-#' model - can be utilised for the meta-analysis of proportions
-#' (Stijnen et al., 2010). This method - implicitly using the logit
-#' transformation - is available (argument \code{method = "GLMM"}) by
-#' calling the \code{\link[metafor]{rma.glmm}} function from R package
-#' \bold{metafor} internally.
-#'
-#' For the logit transformation, a random intercept logistic
-#' regression model is used by default, i.e., argument \code{method =
-#' "GLMM"}. The classic meta-analysis model based on the inverse
-#' variance method can be used instead by setting argument
-#' \code{method} equal to \code{"Inverse"}.
+#' A generalised linear mixed model (GLMM) - more specific, a random
+#' intercept logistic regression model - can be utilised for the
+#' meta-analysis of proportions (Stijnen et al., 2010). This is the
+#' default method for the logit transformation (argument \code{sm =
+#' "PLOGIT"}). Internally, the \code{\link[metafor]{rma.glmm}}
+#' function from R package \bold{metafor} is called to fit a GLMM.
 #'
+#' Classic meta-analysis (Borenstein et al., 2010) utilising the
+#' (un)transformed proportions and corresponding standard errors in
+#' the inverse variance method is conducted by calling the
+#' \code{\link{metagen}} function internally. This is the only
+#' available method for all transformations but the logit
+#' transformation. The classic meta-analysis model with logit
+#' transformed proportions is used by setting argument \code{method =
+#' "Inverse"}.
+#' 
+#' Default settings are utilised for several arguments (assignments
+#' using \code{\link{gs}} function). These defaults can be changed for
+#' the current R session using the \code{\link{settings.meta}}
+#' function.
+#' 
+#' Furthermore, R function \code{\link{update.meta}} can be used to
+#' rerun a meta-analysis with different settings.
+#' 
+#' \subsection{Choice of transformation / meta-analysis method}{
+#' 
 #' Contradictory recommendations on the use of transformations of
 #' proportions have been published in the literature. For example,
 #' Barendregt et al. (2013) recommend the use of the Freeman-Tukey
 #' double arcsine transformation instead of the logit transformation
 #' whereas Warton & Hui (2011) strongly advise to use generalised
 #' linear mixed models with the logit transformation instead of the
-#' arcsine transformation. Schwarzer et al. (2019) describe seriously
-#' misleading results in a meta-analysis with very different sample
-#' sizes due to problems with the back-transformation of the
-#' Freeman-Tukey transformation which requires a single sample
-#' size. Accordingly, Schwarzer et al. (2019) also recommend to use
-#' GLMMs for the meta-analysis of single proportions, however, admit
-#' that individual study weights are not available with this
-#' method. Meta-analysts which require individual study weights should
-#' consider the arcsine or logit transformation.
+#' arcsine transformation.
+#'
+#' Schwarzer et al. (2019) describe seriously misleading results in a
+#' meta-analysis with very different sample sizes due to problems with
+#' the back-transformation of the Freeman-Tukey transformation which
+#' requires a single sample size (Miller, 1978). Accordingly,
+#' Schwarzer et al. (2019) also recommend to use GLMMs for the
+#' meta-analysis of single proportions, however, admit that individual
+#' study weights are not available with this method. Meta-analysts
+#' which require individual study weights should consider the inverse
+#' variance method with the arcsine or logit transformation.
 #'
 #' In order to prevent misleading conclusions for the Freeman-Tukey
 #' double arcsine transformation, sensitivity analyses using other
 #' transformations or using a range of sample sizes should be
 #' conducted (Schwarzer et al., 2019).
+#' }
+#' 
+#' \subsection{Continuity correction}{
+#' 
+#' If the summary measure is equal to "PLOGIT", "PLN", or "PRAW", a
+#' continuity correction is applied if any study has either zero or
+#' all events, i.e., an event probability of either 0 or 1.
+#'
+#' By default, 0.5 is used as continuity correction (argument
+#' \code{incr}). This continuity correction is used both to calculate
+#' individual study results with confidence limits and to conduct
+#' meta-analysis based on the inverse variance method. For GLMMs no
+#' continuity correction is used.
+#' }
+#' 
+#' \subsection{Confidence intervals for individual studies}{
 #' 
 #' Various methods are available to calculate confidence intervals for
 #' individual study results (see Agresti & Coull 1998 and Newcombe
@@ -176,21 +201,85 @@
 #' confidence interval is calculated for individual studies for any
 #' summary measure (argument \code{sm}) as only number of events and
 #' observations are used in the calculation disregarding the chosen
-#' summary measure. Results will be presented for transformed
-#' proportions if argument \code{backtransf = FALSE} in the
-#' \code{\link{print.meta}}, \code{\link{print.summary.meta}}, or
-#' \code{\link{forest.meta}} function. In this case, argument
-#' \code{method.ci = "NAsm"} is used, i.e. confidence intervals based
-#' on the normal approximation based on the summary measure.
+#' transformation.
+#'
+#' Results will be presented for transformed proportions if argument
+#' \code{backtransf = FALSE} in the \code{\link{print.meta}},
+#' \code{\link{print.summary.meta}}, or \code{\link{forest.meta}}
+#' function. In this case, argument \code{method.ci = "NAsm"} is used,
+#' i.e. confidence intervals based on the normal approximation based
+#' on the summary measure.
+#' }
 #' 
-#' Argument \code{pscale} can be used to rescale proportions, e.g.
-#' \code{pscale = 1000} means that proportions are expressed as events
-#' per 1000 observations. This is useful in situations with (very) low
-#' event probabilities.
+#' \subsection{Estimation of between-study variance}{
 #' 
-#' For several arguments defaults settings are utilised (assignments
-#' using \code{\link{gs}} function). These defaults can be changed
-#' using the \code{\link{settings.meta}} function.
+#' The following methods to estimate the between-study variance
+#' \eqn{\tau^2} (argument \code{method.tau}) are available for the
+#' inverse variance method:
+#' \itemize{
+#' \item DerSimonian-Laird estimator (\code{method.tau = "DL"})
+#' \item Paule-Mandel estimator (\code{method.tau = "PM"})
+#' \item Restricted maximum-likelihood estimator (\code{method.tau =
+#'   "REML"})
+#' \item Maximum-likelihood estimator (\code{method.tau = "ML"})
+#' \item Hunter-Schmidt estimator (\code{method.tau = "HS"})
+#' \item Sidik-Jonkman estimator (\code{method.tau = "SJ"})
+#' \item Hedges estimator (\code{method.tau = "HE"})
+#' \item Empirical Bayes estimator (\code{method.tau = "EB"})
+#' }
+#' See \code{\link{metagen}} for more information on these
+#' estimators. Note, the maximum-likelihood method is utilized for
+#' GLMMs.
+#' }
+#' 
+#' \subsection{Hartung-Knapp method}{
+#' 
+#' Hartung and Knapp (2001a,b) proposed an alternative method for
+#' random effects meta-analysis based on a refined variance estimator
+#' for the treatment estimate. Simulation studies (Hartung and Knapp,
+#' 2001a,b; IntHout et al., 2014; Langan et al., 2019) show improved
+#' coverage probabilities compared to the classic random effects
+#' method. However, in rare settings with very homogeneous treatment
+#' estimates, the Hartung-Knapp method can be anti-conservative
+#' (Wiksten et al., 2016). The Hartung-Knapp method is used if
+#' argument \code{hakn = TRUE}.
+#' }
+#' 
+#' \subsection{Prediction interval}{
+#' 
+#' A prediction interval for the proportion in a new study (Higgins et
+#' al., 2009) is calculated if arguments \code{prediction} and
+#' \code{comb.random} are \code{TRUE}. Note, the definition of
+#' prediction intervals varies in the literature. This function
+#' implements equation (12) of Higgins et al., (2009) which proposed a
+#' \emph{t} distribution with \emph{K-2} degrees of freedom where
+#' \emph{K} corresponds to the number of studies in the meta-analysis.
+#' }
+#'
+#' \subsection{Subgroup analysis}{
+#' 
+#' Argument \code{byvar} can be used to conduct subgroup analysis for
+#' a categorical covariate. The \code{\link{metareg}} function can be
+#' used instead for more than one categorical covariate or continuous
+#' covariates.
+#' }
+#' 
+#' \subsection{Specify the null hypothesis of test for an overall proportion}{
+#'
+#' Argument \code{null.effect} can be used to specify the proportion
+#' used under the null hypothesis in a test for an overall effect.
+#'
+#' By default (\code{null.effect = NA}), no hypothesis test is
+#' conducted as it is unclear which value is a sensible choice for the
+#' data at hand.  An overall proportion of 50\%, for example, could be
+#' tested by setting argument \code{null.effect = 0.5}.
+#'
+#' Note, all tests for an overall effect are two-sided with the
+#' alternative hypothesis that the effect is unequal to
+#' \code{null.effect}.
+#' }
+#' 
+#' \subsection{Presentation of meta-analysis results}{
 #' 
 #' Internally, both fixed effect and random effects models are
 #' calculated regardless of values choosen for arguments
@@ -203,56 +292,11 @@
 #' \code{\link{print.meta}} will not print results for the random
 #' effects model if \code{comb.random = FALSE}.
 #' 
-#' If the summary measure is equal to "PRAW", "PLN", or "PLOGIT", a
-#' continuity correction is applied if any study has either zero or
-#' all events, i.e., an event probability of either 0 or 1. By
-#' default, 0.5 is used as continuity correction (argument
-#' \code{incr}). This continuity correction is used both to calculate
-#' individual study results with confidence limits and to conduct
-#' meta-analysis based on the inverse variance method. For GLMMs no
-#' continuity correction is used.
-#' 
-#' Argument \code{byvar} can be used to conduct subgroup analysis for
-#' all methods but GLMMs. Instead use the \code{\link{metareg}}
-#' function for GLMMs which can also be used for continuous
-#' covariates.
-#' 
-#' A prediction interval for the treatment effect of a new study is
-#' calculated (Higgins et al., 2009) if arguments \code{prediction}
-#' and \code{comb.random} are \code{TRUE}.
-#' 
-#' R function \code{\link{update.meta}} can be used to redo the
-#' meta-analysis of an existing metaprop object by only specifying
-#' arguments which should be changed.
-#' 
-#' For the random effects, the method by Hartung and Knapp (2003) is
-#' used to adjust test statistics and confidence intervals if argument
-#' \code{hakn = TRUE}.
-#' 
-#' The DerSimonian-Laird estimate (1986) is used in the random effects
-#' model if \code{method.tau = "DL"}. The iterative Paule-Mandel
-#' method (1982) to estimate the between-study variance is used if
-#' argument \code{method.tau = "PM"}.  Internally, R function
-#' \code{paulemandel} is called which is based on R function
-#' mpaule.default from R package \bold{metRology} from S.L.R. Ellison
-#' <s.ellison at lgc.co.uk>.
-#' 
-#' If R package \bold{metafor} (Viechtbauer 2010) is installed, the
-#' following methods to estimate the between-study variance
-#' \eqn{\tau^2} (argument \code{method.tau}) are also available:
-#' \itemize{
-#' \item Restricted maximum-likelihood estimator (\code{method.tau =
-#'   "REML"})
-#' \item Maximum-likelihood estimator (\code{method.tau = "ML"})
-#' \item Hunter-Schmidt estimator (\code{method.tau = "HS"})
-#' \item Sidik-Jonkman estimator (\code{method.tau = "SJ"})
-#' \item Hedges estimator (\code{method.tau = "HE"})
-#' \item Empirical Bayes estimator (\code{method.tau = "EB"})
+#' Argument \code{pscale} can be used to rescale proportions, e.g.
+#' \code{pscale = 1000} means that proportions are expressed as events
+#' per 1000 observations. This is useful in situations with (very) low
+#' event probabilities.
 #' }
-#' For these methods the R function \code{rma.uni} of R package
-#' \bold{metafor} is called internally. See help page of R function
-#' \code{rma.uni} for more details on these methods to estimate
-#' between-study variance.
 #' 
 #' @return
 #' An object of class \code{c("metaprop", "meta")} with corresponding
@@ -303,8 +347,7 @@
 #' \item{df.Q.LRT}{Degrees of freedom for likelihood-ratio test}
 #' \item{pval.Q.LRT}{P-value of likelihood-ratio test.}
 #' \item{tau}{Square-root of between-study variance.}
-#' \item{se.tau}{Standard error of square-root of between-study
-#'   variance.}
+#' \item{se.tau2}{Standard error of between-study variance.}
 #' \item{C}{Scaling factor utilised internally to calculate common
 #'   tau-squared across subgroups.}
 #' \item{method}{A character string indicating method used for
@@ -448,11 +491,31 @@
 #' \emph{Journal of the Royal Statistical Society: Series A},
 #' \bold{172}, 137--59
 #' 
-#' Knapp G & Hartung J (2003):
-#' Improved tests for a random effects meta-regression with a single
-#' covariate.
+#' Hartung J, Knapp G (2001a):
+#' On tests of the overall treatment effect in meta-analysis with
+#' normally distributed responses.
 #' \emph{Statistics in Medicine},
-#' \bold{22}, 2693--710
+#' \bold{20}, 1771--82
+#' 
+#' Hartung J, Knapp G (2001b):
+#' A refined method for the meta-analysis of controlled clinical
+#' trials with binary outcome.
+#' \emph{Statistics in Medicine},
+#' \bold{20}, 3875--89
+#'
+#' IntHout J, Ioannidis JPA, Borm GF (2014):
+#' The Hartung-Knapp-Sidik-Jonkman method for random effects
+#' meta-analysis is straightforward and considerably outperforms the
+#' standard DerSimonian-Laird method.
+#' \emph{BMC Medical Research Methodology},
+#' \bold{14}, 25
+#'
+#' Langan D, Higgins JPT, Jackson D, Bowden J, Veroniki AA,
+#' Kontopantelis E, et al. (2019):
+#' A comparison of heterogeneity variance estimators in simulated
+#' random-effects meta-analyses.
+#' \emph{Research Synthesis Methods},
+#' \bold{10}, 83--98
 #' 
 #' Miller JJ (1978):
 #' The inverse of the Freeman-Tukey double arcsine transformation.
@@ -465,11 +528,6 @@
 #' \emph{Statistics in Medicine},
 #' \bold{17}, 857--72
 #' 
-#' Paule RC & Mandel J (1982):
-#' Consensus values and weighting factors.
-#' \emph{Journal of Research of the National Bureau of Standards},
-#' \bold{87}, 377--85
-#' 
 #' Pettigrew HM, Gart JJ, Thomas DG (1986):
 #' The bias and higher cumulants of the logarithm of a binomial
 #' variate.
@@ -479,8 +537,8 @@
 #' Schwarzer G, Chemaitelly H, Abu-Raddad LJ, Rücker G (2019):
 #' Seriously misleading results using inverse of Freeman-Tukey double
 #' arcsine transformation in meta-analysis of single proportions.
-#' \emph{Research Synthesis Methods}, 1--8.
-#' https://doi.org/10.1002/jrsm.1348
+#' \emph{Research Synthesis Methods},
+#' \bold{10}, 476--83
 #' 
 #' Stijnen T, Hamza TH, Ozdemir P (2010):
 #' Random effects meta-analysis of event outcome in the framework of
@@ -498,6 +556,12 @@
 #' The arcsine is asinine: the analysis of proportions in ecology.
 #' \emph{Ecology},
 #' \bold{92}, 3--10
+#'
+#' Wiksten A, Rücker G, Schwarzer G (2016):
+#' Hartung-Knapp method is not always conservative compared with
+#' fixed-effect meta-analysis.
+#' \emph{Statistics in Medicine},
+#' \bold{35}, 2503--15
 #' 
 #' @examples
 #' # Meta-analysis using generalised linear mixed model
@@ -867,7 +931,7 @@ metaprop <- function(event, n, studlab,
   }
   else
     exclude <- rep(FALSE, k.All)
-  ##  
+  ##
   if (by) {
     chkmiss(byvar)
     byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
@@ -916,7 +980,7 @@ metaprop <- function(event, n, studlab,
   ##
   if (!missing.subset) {
     event <- event[subset]
-    n   <- n[subset]
+    n <- n[subset]
     studlab <- studlab[subset]
     ##
     exclude <- exclude[subset]
@@ -963,11 +1027,11 @@ metaprop <- function(event, n, studlab,
   ##
   ##
   sel <- switch(sm,
-                PFT = rep(FALSE, length(event)),
+                PLOGIT = event == 0 | (n - event) == 0,
                 PAS = rep(FALSE, length(event)),
-                PRAW =   event == 0 | (n - event) == 0,
+                PFT = rep(FALSE, length(event)),
                 PLN =    event == 0 | (n - event) == 0,
-                PLOGIT = event == 0 | (n - event) == 0)
+                PRAW =   event == 0 | (n - event) == 0)
   ##
   sparse <- any(sel, na.rm = TRUE)
   ##
@@ -984,21 +1048,21 @@ metaprop <- function(event, n, studlab,
   else
     incr.event <- rep(0, k.all)
   ##  
-  if (sm == "PFT") {
-    TE <- 0.5 * (asin(sqrt(event / (n + 1))) + asin(sqrt((event + 1) / (n + 1))))
-    seTE <- sqrt(1 / (4 * n + 2))
-    transf.null.effect <- asin(sqrt(null.effect))
+  if (sm == "PLOGIT") {
+    TE <- log((event + incr.event) / (n - event + incr.event))
+    seTE <- sqrt(1 / (event + incr.event) +
+                 1 / ((n - event + incr.event)))
+    transf.null.effect <- log(null.effect / (1 - null.effect))
   }
   else if (sm == "PAS") {
     TE <- asin(sqrt(event / n))
     seTE <- sqrt(0.25 * (1 / n))
     transf.null.effect <- asin(sqrt(null.effect))
   }
-  else if (sm == "PRAW") {
-    TE <- event / n
-    seTE <- sqrt((event + incr.event) * (n - event + incr.event) /
-                 (n + 2 * incr.event)^3)
-    transf.null.effect <- null.effect
+  else if (sm == "PFT") {
+    TE <- 0.5 * (asin(sqrt(event / (n + 1))) + asin(sqrt((event + 1) / (n + 1))))
+    seTE <- sqrt(1 / (4 * n + 2))
+    transf.null.effect <- asin(sqrt(null.effect))
   }
   else if (sm == "PLN") {
     TE <- log((event + incr.event) / (n + incr.event))
@@ -1009,11 +1073,11 @@ metaprop <- function(event, n, studlab,
                    )
     transf.null.effect <- log(null.effect)
   }
-  else if (sm == "PLOGIT") {
-    TE <- log((event + incr.event) / (n - event + incr.event))
-    seTE <- sqrt(1 / (event + incr.event) +
-                 1 / ((n - event + incr.event)))
-    transf.null.effect <- log(null.effect / (1 - null.effect))
+  else if (sm == "PRAW") {
+    TE <- event / n
+    seTE <- sqrt((event + incr.event) * (n - event + incr.event) /
+                 (n + 2 * incr.event)^3)
+    transf.null.effect <- null.effect
   }
   ##
   ## Calculate confidence intervals
@@ -1060,12 +1124,7 @@ metaprop <- function(event, n, studlab,
   }
   ##  
   if (method.ci == "NAsm") {
-    if (sm == "PLN") {
-      lower.study <- exp(lower.study)
-      upper.study <- exp(upper.study)
-    }
-    ##
-    else if (sm == "PLOGIT") {
+    if (sm == "PLOGIT") {
       lower.study <- logit2p(lower.study)
       upper.study <- logit2p(upper.study)
     }
@@ -1080,6 +1139,11 @@ metaprop <- function(event, n, studlab,
       upper.study <- asin2p(upper.study, n, value = "upper", warn = FALSE)
     }
     ##
+    else if (sm == "PLN") {
+      lower.study <- exp(lower.study)
+      upper.study <- exp(upper.study)
+    }
+    ##
     lower.study[lower.study < 0] <- 0
     upper.study[upper.study > 1] <- 1
   }
@@ -1135,7 +1199,7 @@ metaprop <- function(event, n, studlab,
                ##
                control = control)
   ##
-  if (method != "GLMM" & by & tau.common) {
+  if (by & tau.common) {
     ## Estimate common tau-squared across subgroups
     hcc <- hetcalc(TE, seTE, method.tau, TE.tau,
                    level.comb, byvar, control)
@@ -1299,14 +1363,7 @@ metaprop <- function(event, n, studlab,
       res$H.resid <- ci.H.resid$TE
       res$lower.H.resid <- ci.H.resid$lower
       res$upper.H.resid <- ci.H.resid$upper
-    }
-    else {
-      res$H.resid <- hcc$H.resid
-      res$lower.H.resid <- hcc$lower.H.resid
-      res$upper.H.resid <- hcc$upper.H.resid
-    }
-    ##
-    if (!tau.common || method.tau == "DL") {
+      ##
       ci.I2.resid <- isquared(res$Q.w.fixed, res$df.Q.w, level.comb)
       ##
       res$I2.resid <- ci.I2.resid$TE
@@ -1314,9 +1371,28 @@ metaprop <- function(event, n, studlab,
       res$upper.I2.resid <- ci.I2.resid$upper
     }
     else {
-      res$I2.resid <- hcc$I2.resid
-      res$lower.I2.resid <- hcc$lower.I2.resid
-      res$upper.I2.resid <- hcc$upper.I2.resid
+      if (is.glmm) {
+        ci.H.resid <- calcH(res$Q.w.fixed, res$df.Q.w, level.comb)
+        ##
+        res$H.resid <- ci.H.resid$TE
+        res$lower.H.resid <- ci.H.resid$lower
+        res$upper.H.resid <- ci.H.resid$upper
+        ##
+        ci.I2.resid <- isquared(res$Q.w.fixed, res$df.Q.w, level.comb)
+        ##
+        res$I2.resid <- ci.I2.resid$TE
+        res$lower.I2.resid <- ci.I2.resid$lower
+        res$upper.I2.resid <- ci.I2.resid$upper
+      }
+      else {
+        res$H.resid <- hcc$H.resid
+        res$lower.H.resid <- hcc$lower.H.resid
+        res$upper.H.resid <- hcc$upper.H.resid
+        ##
+        res$I2.resid <- hcc$I2.resid
+        res$lower.I2.resid <- hcc$lower.I2.resid
+        res$upper.I2.resid <- hcc$upper.I2.resid
+      }
     }
     ##
     res$event.e.w <- NULL
